==========================================================
 Native Delayed Delivery - ``native_delayed_delivery``
==========================================================

.. versionadded:: 5.5

.. contents::
    :local:
.. currentmodule:: kombu.transport.native_delayed_delivery

.. automodule:: kombu.transport.native_delayed_delivery
    :members:
    :undoc-members:
